==> jc-1.4.0.tar.gz: soot/tagkit/SourcePositionTag.h <==
// public class soot.tagkit.SourcePositionTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f112a0e13b029d9 soot_tagkit_PositionTag
// @dep_class 50f5695cb4eac404 soot_tagkit_SourcePositionTag

// header file dependencies
// @dep_header soot_tagkit_PositionTag

#include "soot/tagkit/PositionTag.h"

#ifndef _JC_soot_tagkit_SourcePositionTag_H_
#define _JC_soot_tagkit_SourcePositionTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourcePositionTag$sub_refs	_jc_soot_tagkit_SourcePositionTag$sub_refs;
typedef struct _jc_soot_tagkit_SourcePositionTag$sub_nonrefs	_jc_soot_tagkit_SourcePositionTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourcePositionTag$refs	_jc_soot_tagkit_SourcePositionTag$refs;
typedef struct _jc_soot_tagkit_SourcePositionTag$nonrefs	_jc_soot_tagkit_SourcePositionTag$nonrefs;
typedef struct _jc_soot_tagkit_SourcePositionTag$object	_jc_soot_tagkit_SourcePositionTag$object;

typedef const struct _jc_soot_tagkit_SourcePositionTag$vmethods	_jc_soot_tagkit_SourcePositionTag$vmethods;
typedef const struct _jc_soot_tagkit_SourcePositionTag$vtable	_jc_soot_tagkit_SourcePositionTag$vtable;
typedef const struct _jc_soot_tagkit_SourcePositionTag$vtype	_jc_soot_tagkit_SourcePositionTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourcePositionTag$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_tagkit_SourcePositionTag$object *, jint, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourcePositionTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_tagkit_SourcePositionTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourcePositionTag$object *);
};

// Vtable
struct _jc_soot_tagkit_SourcePositionTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_PositionTag$vmethods	soot_tagkit_PositionTag;
	_jc_soot_tagkit_SourcePositionTag$vmethods	soot_tagkit_SourcePositionTag;
};

// Vtype
struct _jc_soot_tagkit_SourcePositionTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourcePositionTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourcePositionTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourcePositionTag$refs {
    _jc_soot_tagkit_SourcePositionTag$sub_refs	soot_tagkit_SourcePositionTag;
    _jc_soot_tagkit_PositionTag$sub_refs	soot_tagkit_PositionTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourcePositionTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourcePositionTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_PositionTag$sub_nonrefs	soot_tagkit_PositionTag;
    _jc_soot_tagkit_SourcePositionTag$sub_nonrefs	soot_tagkit_SourcePositionTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourcePositionTag$object {
	_jc_soot_tagkit_SourcePositionTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourcePositionTag$vtype	*vtype;
	_jc_soot_tagkit_SourcePositionTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourcePositionTag$vtype _jc_soot_tagkit_SourcePositionTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourcePositionTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourcePositionTag$class_object;

#endif	/* _JC_soot_tagkit_SourcePositionTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/SourcePositionTag.h <==
// public class soot.tagkit.SourcePositionTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f112a0e13b029d9 soot_tagkit_PositionTag
// @dep_class 50f5695cb4eac404 soot_tagkit_SourcePositionTag

// header file dependencies
// @dep_header soot_tagkit_PositionTag

#include "soot/tagkit/PositionTag.h"

#ifndef _JC_soot_tagkit_SourcePositionTag_H_
#define _JC_soot_tagkit_SourcePositionTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourcePositionTag$sub_refs	_jc_soot_tagkit_SourcePositionTag$sub_refs;
typedef struct _jc_soot_tagkit_SourcePositionTag$sub_nonrefs	_jc_soot_tagkit_SourcePositionTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourcePositionTag$refs	_jc_soot_tagkit_SourcePositionTag$refs;
typedef struct _jc_soot_tagkit_SourcePositionTag$nonrefs	_jc_soot_tagkit_SourcePositionTag$nonrefs;
typedef struct _jc_soot_tagkit_SourcePositionTag$object	_jc_soot_tagkit_SourcePositionTag$object;

typedef const struct _jc_soot_tagkit_SourcePositionTag$vmethods	_jc_soot_tagkit_SourcePositionTag$vmethods;
typedef const struct _jc_soot_tagkit_SourcePositionTag$vtable	_jc_soot_tagkit_SourcePositionTag$vtable;
typedef const struct _jc_soot_tagkit_SourcePositionTag$vtype	_jc_soot_tagkit_SourcePositionTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourcePositionTag$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_tagkit_SourcePositionTag$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourcePositionTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourcePositionTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourcePositionTag$method_info$getName$bec186f2ce7e1882;

// Virtual methods structure
struct _jc_soot_tagkit_SourcePositionTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourcePositionTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_SourcePositionTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_PositionTag$vmethods	soot_tagkit_PositionTag;
	_jc_soot_tagkit_SourcePositionTag$vmethods	soot_tagkit_SourcePositionTag;
};

// Vtype
struct _jc_soot_tagkit_SourcePositionTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourcePositionTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourcePositionTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourcePositionTag$refs {
    _jc_soot_tagkit_SourcePositionTag$sub_refs	soot_tagkit_SourcePositionTag;
    _jc_soot_tagkit_PositionTag$sub_refs	soot_tagkit_PositionTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourcePositionTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourcePositionTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_PositionTag$sub_nonrefs	soot_tagkit_PositionTag;
    _jc_soot_tagkit_SourcePositionTag$sub_nonrefs	soot_tagkit_SourcePositionTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourcePositionTag$object {
	_jc_soot_tagkit_SourcePositionTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourcePositionTag$vtype	*vtype;
	_jc_soot_tagkit_SourcePositionTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourcePositionTag$vtype _jc_soot_tagkit_SourcePositionTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourcePositionTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourcePositionTag$class_object;

#endif	/* _JC_soot_tagkit_SourcePositionTag_H_ */
